import { Routes as BaseRoutes, Navigate, Route } from "react-router-dom";
import { Suspense } from "react";
import LoadingComponent from "./components/Loading";
import DashboardLayout from "./layouts/DashboardLayout";
import Login from "./pages/Auth/Login";
import SignUp from "./pages/Auth/SignUp";
import Dashboard from "./pages/Dashboard";
import Vehicles from "./pages/Vehicles";
import { useSelector } from "react-redux";
import { RootState } from "./redux/reducers";
import { useCookies } from "react-cookie";

interface ProtectedRouteProps {
	component: JSX.Element;
	cookies?: { get: (key: string) => string | null };
}
function ProtectedRoute({ component }: ProtectedRouteProps): JSX.Element {
	const [cookies] = useCookies(["authToken"]);
	const isCookiePresent = !!cookies?.authToken;
	const isAuthenticated = useSelector(
		(state: RootState) => state.authReducer.isAuthenticated
	);

	if (!isAuthenticated && !isCookiePresent) {
		return <Navigate to="/auth/login" replace />;
	}

	return component;
}

export default function AppRouter() {
	return (
		<Suspense fallback={<LoadingComponent />}>
			<BaseRoutes>
				<Route element={<Navigate to="/auth/login" replace />} index />

				<Route path="/auth">
					<Route
						path=""
						element={<Navigate to="/auth/login" replace />}
						index
					/>
					<Route path="login" element={<Login />} />
					<Route path="signup" element={<SignUp />} />
				</Route>
				<Route path="/panel" element={<DashboardLayout />}>
					<Route
						path="dashboard"
						element={<ProtectedRoute component={<Dashboard />} />}
					/>
					<Route
						path="vehicles"
						element={<ProtectedRoute component={<Vehicles />} />}
					/>
					<Route path="*" element={<>404</>} />
				</Route>
				<Route path="*" element={<>404</>} />
			</BaseRoutes>
		</Suspense>
	);
}
